DateTimePicker | django_cradmin API Document

    import DateTimePicker from 'django_cradmin/scripts/django_cradmin/DateTimePicker.js'

public class | source

# DateTimePicker

#### Extends:

ievv_jsbase/widget/AbstractWidget~AbstractWidget → DateTimePicker

## Constructor Summary

Public Constructor
public | constructor(element: *) |

## Member Summary

Public Members
public | calendarCoordinator: * |
public | elementCreator: * |
public | logger: * |
public | monthlyCalendarCoordinator: * |
public | nowMomentObject: * |
public | selectedMomentObject: * |

## Method Summary

Public Methods
public | destroy() |
public | getDefaultConfig(): * |

## Public Constructors

### public constructor(element: *) source

#### Params:

Name | Type | Attribute | Description
element | * |  |

## Public Members

### public calendarCoordinator: * source

### public elementCreator: * source

### public logger: * source

### public monthlyCalendarCoordinator: * source

### public nowMomentObject: * source

### public selectedMomentObject: * source

## Public Methods

### public destroy() source

### public getDefaultConfig(): * source

#### Return:

*